@@ -1,16 +1,17 @@
-from typing import Mapping, Dict, Any, Tuple, List
+from typing import Mapping, Dict, Any, List
 from json.decoder import JSONDecodeError
 from logging import getLogger
-from datetime import datetime, timedelta
+from datetime import datetime
 import asyncio
 import aiohttp
+import requests
 
 from pyot.core import exceptions as exc
 from pyot.pipeline.token import PipelineToken, RequestToken
 from pyot.pipeline.objects import StoreObject
 from pyot.pipeline.handler import ErrorHandler
 from pyot.limiters.core import BaseLimiter
-from pyot.utils import import_class
+from pyot.utils import import_class, thread_run
 
 LOGGER = getLogger(__name__)
 
@@ -44,16 +45,21 @@ class RiotAPI(StoreObject):
         url = await self._endpoints.resolve(token)
         headers = {"X-Riot-Token": self._api_key}
         request_token = RequestToken()
+        decode_failed = False
         while await request_token.run_or_raise():
             try:
                 limit_token = await self._rate_limiter.get_limit_token(server, regmethod)
                 if await limit_token.run_or_wait():
                     self._rate_limiter.validate_bucket(server, regmethod, limit_token)
                     continue
-                response = await session.request(method=request_method, url=url, headers=headers, json=body)
+                if decode_failed:
+                    response = await thread_run(requests.request, method=request_method, url=url, headers=headers, json=body)
+                    response.status = response.status_code
+                else:
+                    response = await session.request(method=request_method, url=url, headers=headers, json=body)
                 LOGGER.log(self._log_level, f"[Trace: {self._game.upper()} > RiotAPI] {request_method}: {self._log_template(token)}")
             except Exception as e:
-                LOGGER.warning(f"[Trace: {self._game.upper()} > RiotAPI] WARNING: '{e.__class__.__name__}: {e}' was raised during the request and ignored")
+                LOGGER.warning(f"[Trace: {self._game.upper()} > RiotAPI] WARNING: '{e.__class__.__name__}: {e}' was raised during the request")
                 response = None
 
             await self._rate_limiter.stream(response, server, regmethod, limit_token)
@@ -62,10 +68,17 @@ class RiotAPI(StoreObject):
             if response and response.status == 200:
                 try:
                     try:
-                        return await asyncio.wait_for(response.json(encoding="utf-8"), timeout=5)
+                        if not decode_failed:
+                            return await asyncio.wait_for(response.json(encoding="utf-8"), timeout=5)
+                        else:
+                            return await thread_run(response.json, encoding="utf-8")
                     except JSONDecodeError:
-                        return await asyncio.wait_for(response.text(), timeout=5)
+                        if not decode_failed:
+                            return await asyncio.wait_for(response.text(), timeout=5)
+                        else:
+                            return await thread_run(response.text)
                 except asyncio.TimeoutError:
+                    decode_failed = True
                     code = 602
 
             try:
@@ -118,10 +131,12 @@ class RiotAPIEndpoint:
             "league_v4_master_league": "/lol/league/v4/masterleagues/by-queue/{queue}",
             "league_v4_entries_by_division": "/lol/league/v4/entries/{queue}/{tier}/{division}",
             "league_v4_league_by_league_id": "/lol/league/v4/leagues/{id}",
-            "status_v3_shard_data": "/lol/status/v3/shard-data",
+            "status_v4_platform_data": "/lol/status/v4/platform-data",
             "match_v4_match": "/lol/match/v4/matches/{id}",
             "match_v4_timeline": "/lol/match/v4/timelines/by-match/{id}",
             "match_v4_matchlist": "/lol/match/v4/matchlists/by-account/{account_id}",
+            "match_v4_tournament_match": "/lol/match/v4/matches/{id}/by-tournament-code/{tournament_code}",
+            "match_v4_tournament_matches": "/lol/match/v4/matches/by-tournament-code/{tournament_code}/ids", 
             "spectator_v4_current_game": "/lol/spectator/v4/active-games/by-summoner/{summoner_id}",
             "spectator_v4_featured_games": "/lol/spectator/v4/featured-games",
             "summoner_v4_by_name": "/lol/summoner/v4/summoners/by-name/{name}",
@@ -157,12 +172,14 @@ class RiotAPIEndpoint:
             "ranked_v1_leaderboards": "/lor/ranked/v1/leaderboards",
             "match_v1_matchlist": "/lor/match/v1/matches/by-puuid/{puuid}/ids",
             "match_v1_match": "/lor/match/v1/matches/{id}",
+            "status_v1_platform_data": "/lor/status/v1/platform-data",
         },
         "val": {
             "match_v1_match": "/val/match/v1/matches/{id}",
             "match_v1_matchlist": "/val/match/v1/matchlists/by-puuid/{puuid}",
             "match_v1_recent": "/val/match/v1/recent-matches/by-queue/{queue}",
             "content_v1_contents": "/val/content/v1/contents",
+            "status_v1_platform_data": "/val/status/v1/platform-data",
         }
     }
     
